Improve this Doc View Source

A container for the options set by the `ngModelOptions` directive

## Methods

- ###

  `getOption(name);`

  Returns the value of the given option

  #### Parameters

  Param | Type | Details
  --- | --- | ---
  name | string | the name of the option to retrieve

  #### Returns

  * | the value of the option

- ###

  `createChild(options);`

  #### Parameters

  Param | Type | Details
  --- | --- | ---
  options | Object | a hash of options for the new child that will override the parent's options

  #### Returns

  ModelOptions | a new `ModelOptions` object initialized with the given options.